@@ -8,33 +8,42 @@
 #include <memory>
 
 #include "post.h"
+#include "posteditorbackend.h"
+
+class QTimer;
+class AbstractAccount;
 
 class AttachmentEditorModel : public QAbstractListModel
 {
     Q_OBJECT
-    Q_PROPERTY(Post *post READ post WRITE setPost NOTIFY postChanged)
     Q_PROPERTY(int count READ count NOTIFY countChanged)
 public:
-    explicit AttachmentEditorModel(QObject *parent = nullptr);
+    explicit AttachmentEditorModel(QObject *parent, AbstractAccount *account);
 
     enum ExtraRole {
-        Preview = Qt::UserRole + 1,
-        Description,
+        PreviewRole = Qt::UserRole + 1,
+        DescriptionRole,
     };
 
-    Post *post() const;
     int count() const;
-    void setPost(Post *post);
 
-    Q_INVOKABLE int rowCount(const QModelIndex &parent = QModelIndex()) const override;
-    bool setData(const QModelIndex &index, const QVariant &value, int role) override;
+    Q_INVOKABLE int rowCount(const QModelIndex &parent = {}) const override;
     QVariant data(const QModelIndex &index, int role) const override;
     QHash<int, QByteArray> roleNames() const override;
+    const QVector<Attachment *> &attachments() const;
+
+public Q_SLOTS:
+    QNetworkReply *append(const QUrl &fileName);
+    void appendExisting(Attachment *attachment);
+    void removeAttachment(int row);
+    void setDescription(int row, const QString &description);
 
 Q_SIGNALS:
     void postChanged();
     void countChanged();
 
 private:
-    Post *m_scratch;
+    QVector<Attachment *> m_attachments;
+    QHash<QString, QTimer *> m_updateTimers;
+    AbstractAccount *m_account;
 };
