@@ -93,7 +93,7 @@ void TimelineModel::fetchedTimeline(const QByteArray &data)
     if (!m_timeline.isEmpty()) {
         const auto postOld = m_timeline.first();
         const auto postNew = posts.first();
-        if (postOld->postId() > postNew->postId()) {
+        if (postOld->originalPostId() > postNew->originalPostId()) {
             const int row = m_timeline.size();
             const int last = row + posts.size() - 1;
             beginInsertRows({}, row, last);
@@ -122,13 +122,13 @@ void TimelineModel::fetchMore(const QModelIndex &parent)
 
     const auto p = m_timeline.last();
 
-    fillTimeline(p->m_original_post_id);
+    fillTimeline(p->originalPostId());
 }
 
 bool TimelineModel::canFetchMore(const QModelIndex &parent) const
 {
     Q_UNUSED(parent);
-    return !m_loading;
+    return true;
 }
 
 int TimelineModel::rowCount(const QModelIndex &parent) const
@@ -158,51 +158,33 @@ void TimelineModel::actionReply(const QModelIndex &index)
 
 void TimelineModel::actionFavorite(const QModelIndex &index)
 {
-    int row = index.row();
-    auto p = m_timeline[row];
-
-    if (!p->m_isFavorite) {
-        m_account->favorite(p);
-        p->m_isFavorite = true;
-    } else {
-        m_account->unfavorite(p);
-        p->m_isFavorite = false;
-    }
-
-    Q_EMIT dataChanged(index, index);
+    const int row = index.row();
+    const auto post = m_timeline[row];
+    AbstractTimelineModel::actionFavorite(index, post);
 }
 
 void TimelineModel::actionRepeat(const QModelIndex &index)
 {
-    int row = index.row();
-    auto p = m_timeline[row];
-
-    if (!p->m_isRepeated) {
-        m_account->repeat(p);
-        p->m_isRepeated = true;
-    } else {
-        m_account->unrepeat(p);
-        p->m_isRepeated = false;
-    }
-
-    Q_EMIT dataChanged(index, index);
+    const int row = index.row();
+    const auto post = m_timeline[row];
+    AbstractTimelineModel::actionRepeat(index, post);
 }
 
 void TimelineModel::actionVis(const QModelIndex &index)
 {
-    int row = index.row();
-    auto p = m_timeline[row];
+    const int row = index.row();
+    const auto p = m_timeline[row];
 
-    p->m_attachments_visible ^= true;
+    p->setAttachmentsVisible(!p->attachmentsVisible());
 
     Q_EMIT dataChanged(index, index);
 }
 
 void TimelineModel::actionVote(const QModelIndex &index, const QList<int> &choices)
 {
-    int row = index.row();
-    auto post = m_timeline[row];
-    auto poll = post->poll();
+    const int row = index.row();
+    const auto post = m_timeline[row];
+    const auto poll = post->poll();
     Q_ASSERT(poll);
 
     QJsonObject obj;
@@ -221,8 +203,7 @@ void TimelineModel::actionVote(const QModelIndex &index, const QList<int> &choic
         for (auto &post : m_timeline) {
             if (post->poll() && post->poll()->id() == id) {
                 const auto newPoll = QJsonDocument::fromJson(reply->readAll()).object();
-                delete post->poll();
-                post->setPoll(new Poll(newPoll));
+                post->setPollJson(newPoll);
                 Q_EMIT dataChanged(this->index(i, 0), this->index(i, 0), {PollRole});
                 break;
             }
@@ -231,12 +212,48 @@ void TimelineModel::actionVote(const QModelIndex &index, const QList<int> &choic
     });
 }
 
+void TimelineModel::actionBookmark(const QModelIndex &index)
+{
+    int row = index.row();
+    auto p = m_timeline[row];
+
+    if (!p->bookmarked()) {
+        m_account->bookmark(p);
+        p->setBookmarked(true);
+    } else {
+        m_account->unbookmark(p);
+        p->setBookmarked(false);
+    }
+
+    Q_EMIT dataChanged(index, index);
+}
+
+void TimelineModel::actionRedraft(const QModelIndex &index, bool isEdit)
+{
+    int row = index.row();
+    auto p = m_timeline[row];
+
+    AbstractTimelineModel::actionRedraft(index, p, isEdit);
+}
+
+void TimelineModel::actionDelete(const QModelIndex &index)
+{
+    int row = index.row();
+    auto p = m_timeline[row];
+
+    AbstractTimelineModel::actionDelete(index, p);
+
+    beginRemoveRows({}, row, row);
+    m_timeline.removeAt(row);
+    endRemoveRows();
+}
+
 void TimelineModel::handleEvent(AbstractAccount::StreamingEventType eventType, const QByteArray &payload)
 {
     if (eventType == AbstractAccount::StreamingEventType::DeleteEvent) {
         int i = 0;
         for (const auto &post : std::as_const(m_timeline)) {
-            if (post->m_original_post_id.toUtf8() == payload) {
+            if (post->originalPostId().toUtf8() == payload) {
                 beginRemoveRows({}, i, i);
                 m_timeline.removeAt(i);
                 endRemoveRows();
@@ -245,4 +262,4 @@ void TimelineModel::handleEvent(AbstractAccount::StreamingEventType eventType, c
             i++;
         }
     }
-}
+}
\ No newline at end of file
