@@ -4,9 +4,9 @@
 
 #pragma once
 
+#include "abstractaccount.h"
 #include "abstracttimelinemodel.h"
 #include "accountmanager.h"
-#include "abstractaccount.h"
 #include "post.h"
 #include <QAbstractListModel>
 
@@ -32,6 +32,9 @@ public Q_SLOTS:
     void actionRepeat(const QModelIndex &index);
     void actionVis(const QModelIndex &index);
     void actionVote(const QModelIndex &index, const QList<int> &choices);
+    void actionBookmark(const QModelIndex &index);
+    void actionRedraft(const QModelIndex &index, bool isEdit);
+    void actionDelete(const QModelIndex &index);
 
 Q_SIGNALS:
     void wantReply(AbstractAccount *account, Post *post, const QModelIndex &index);
